==> mozc_0.11.365.102-0maemo1.tar.gz: mozc-0.11.365.102/gui/config_dialog/keymap_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>mozc::gui::KeyMapEditorDialog</name>
    <message>
        <source>Conversion</source>
        <translation>変換中</translation>
    </message>
    <message>
        <source>Composition</source>
        <translation>変換前入力中</translation>
    </message>
    <message>
        <source>DirectInput</source>
        <translation>直接入力</translation>
    </message>
    <message>
        <source>Precomposition</source>
        <translation>入力文字なし</translation>
    </message>
    <message>
        <source>Prediction</source>
        <translation>サジェスト選択中</translation>
    </message>
    <message>
        <source>Suggestion</source>
        <translation>サジェスト表示中</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>左の文字を削除</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation>最後の学習をキャンセル</translation>
    </message>
    <message>
        <source>Commit</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>CommitFirstSuggestion</source>
        <translation>最初の予測候補を確定</translation>
    </message>
    <message>
        <source>CommitOnlyFirstSegment</source>
        <translation>最初の文節のみを確定</translation>
    </message>
    <message>
        <source>Convert</source>
        <translation>変換</translation>
    </message>
    <message>
        <source>ConvertNext</source>
        <translation>次候補を選択</translation>
    </message>
    <message>
        <source>ConvertNextPage</source>
        <translation>次候補ページを選択</translation>
    </message>
    <message>
        <source>ConvertPrev</source>
        <translation>前候補を選択</translation>
    </message>
    <message>
        <source>ConvertPrevPage</source>
        <translation>前候補ページを選択</translation>
    </message>
    <message>
        <source>ConvertToFullAlphanumeric</source>
        <translation>全角英数に変換</translation>
    </message>
    <message>
        <source>ConvertToFullKatakana</source>
        <translation>全角カタカナに変換</translation>
    </message>
    <message>
        <source>ConvertToHalfKatakana</source>
        <translation>半角カタカナに変換</translation>
    </message>
    <message>
        <source>ConvertToHalfAlphanumeric</source>
        <translation>半角英数に変換</translation>
    </message>
    <message>
        <source>ConvertToHalfWidth</source>
        <translation>半角に変換</translation>
    </message>
    <message>
        <source>ConvertToHiragana</source>
        <translation>ひらがなに変換</translation>
    </message>
    <message>
        <source>ConvertWithoutHistory</source>
        <translation>学習を使わずに変換</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>右の文字を削除</translation>
    </message>
    <message>
        <source>DisplayAsFullAlphanumeric</source>
        <translation>全角英数に表示切替</translation>
    </message>
    <message>
        <source>DisplayAsFullKatakana</source>
        <translation>全角カタカナに表示切替</translation>
    </message>
    <message>
        <source>DisplayAsHalfKatakana</source>
        <translation>半角カタカナに表示切替</translation>
    </message>
    <message>
        <source>DisplayAsHalfAlphanumeric</source>
        <translation>半角英数に表示切替</translation>
    </message>
    <message>
        <source>DisplayAsHalfWidth</source>
        <translation>半角に表示切替</translation>
    </message>
    <message>
        <source>DisplayAsHiragana</source>
        <translation>ひらがなに表示切替</translation>
    </message>
    <message>
        <source>IMEOff</source>
        <translation>IME を無効化</translation>
    </message>
    <message>
        <source>IMEOn</source>
        <translation>IME を有効化</translation>
    </message>
    <message>
        <source>InputModeFullAlphanumeric</source>
        <translation>全角英数に入力切替</translation>
    </message>
    <message>
        <source>InputModeFullKatakana</source>
        <translation>全角カタカナに入力切替</translation>
    </message>
    <message>
        <source>InputModeHalfAlphanumeric</source>
        <translation>半角英数に入力切替</translation>
    </message>
    <message>
        <source>InputModeHalfKatakana</source>
        <translation>半角カタカナに入力切替</translation>
    </message>
    <message>
        <source>InputModeHiragana</source>
        <translation>ひらがなに入力切替</translation>
    </message>
    <message>
        <source>InsertAlternateSpace</source>
        <translation>代替空白文字を入力</translation>
    </message>
    <message>
        <source>InsertFullSpace</source>
        <translation>全角空白を入力</translation>
    </message>
    <message>
        <source>InsertHalfSpace</source>
        <translation>半角空白を入力</translation>
    </message>
    <message>
        <source>InsertSpace</source>
        <translation>空白を入力</translation>
    </message>
    <message>
        <source>MoveCursorLeft</source>
        <translation>カーソルを左に移動</translation>
    </message>
    <message>
        <source>MoveCursorRight</source>
        <translation>カーソルを右に移動</translation>
    </message>
    <message>
        <source>MoveCursorToBeginning</source>
        <translation>カーソルを左端に移動</translation>
    </message>
    <message>
        <source>MoveCursorToEnd</source>
        <translation>カーソルを右端に移動</translation>
    </message>
    <message>
        <source>PredictAndConvert</source>
        <translation>予測変換</translation>
    </message>
    <message>
        <source>SegmentFocusFirst</source>
        <translation>文節を左端に移動</translation>
    </message>
    <message>
        <source>SegmentFocusLast</source>
        <translation>文節を右端に移動</translation>
    </message>
    <message>
        <source>SegmentFocusLeft</source>
        <translation>文節を左に移動</translation>
    </message>
    <message>
        <source>SegmentFocusRight</source>
        <translation>文節を右に移動</translation>
    </message>
    <message>
        <source>SegmentWidthExpand</source>
        <translation>文節を伸ばす</translation>
    </message>
    <message>
        <source>SegmentWidthShrink</source>
        <translation>文節を縮める</translation>
    </message>
    <message>
        <source>SwitchKanaType</source>
        <translation>ひらがな・カタカナを切替</translation>
    </message>
    <message>
        <source>ToggleAlphanumericMode</source>
        <translation>英数入力切り替え</translation>
    </message>
</context>
</TS>

==> mozc_1.1.690.102-0maemo1.tar.gz: mozc-1.1.690.102/gui/config_dialog/keymap_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>mozc::gui::KeyMapEditorDialog</name>
    <message>
        <source>Conversion</source>
        <translation>変換中</translation>
    </message>
    <message>
        <source>Composition</source>
        <translation>変換前入力中</translation>
    </message>
    <message>
        <source>DirectInput</source>
        <translation>直接入力</translation>
    </message>
    <message>
        <source>Precomposition</source>
        <translation>入力文字なし</translation>
    </message>
    <message>
        <source>Prediction</source>
        <translation>サジェスト選択中</translation>
    </message>
    <message>
        <source>Suggestion</source>
        <translation>サジェスト表示中</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>左の文字を削除</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation>最後の学習をキャンセル</translation>
    </message>
    <message>
        <source>Commit</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>CommitFirstSuggestion</source>
        <translation>最初の予測候補を確定</translation>
    </message>
    <message>
        <source>CommitOnlyFirstSegment</source>
        <translation>最初の文節のみを確定</translation>
    </message>
    <message>
        <source>Convert</source>
        <translation>変換</translation>
    </message>
    <message>
        <source>ConvertNext</source>
        <translation>次候補を選択</translation>
    </message>
    <message>
        <source>ConvertNextPage</source>
        <translation>次候補ページを選択</translation>
    </message>
    <message>
        <source>ConvertPrev</source>
        <translation>前候補を選択</translation>
    </message>
    <message>
        <source>ConvertPrevPage</source>
        <translation>前候補ページを選択</translation>
    </message>
    <message>
        <source>ConvertToFullAlphanumeric</source>
        <translation>全角英数に変換</translation>
    </message>
    <message>
        <source>ConvertToFullKatakana</source>
        <translation>全角カタカナに変換</translation>
    </message>
    <message>
        <source>ConvertToHalfKatakana</source>
        <translation>半角カタカナに変換</translation>
    </message>
    <message>
        <source>ConvertToHalfAlphanumeric</source>
        <translation>半角英数に変換</translation>
    </message>
    <message>
        <source>ConvertToHalfWidth</source>
        <translation>半角に変換</translation>
    </message>
    <message>
        <source>ConvertToHiragana</source>
        <translation>ひらがなに変換</translation>
    </message>
    <message>
        <source>ConvertWithoutHistory</source>
        <translation>学習を使わずに変換</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>右の文字を削除</translation>
    </message>
    <message>
        <source>DisplayAsFullAlphanumeric</source>
        <translation>全角英数に表示切替</translation>
    </message>
    <message>
        <source>DisplayAsFullKatakana</source>
        <translation>全角カタカナに表示切替</translation>
    </message>
    <message>
        <source>DisplayAsHalfKatakana</source>
        <translation>半角カタカナに表示切替</translation>
    </message>
    <message>
        <source>DisplayAsHalfAlphanumeric</source>
        <translation>半角英数に表示切替</translation>
    </message>
    <message>
        <source>DisplayAsHalfWidth</source>
        <translation>半角に表示切替</translation>
    </message>
    <message>
        <source>DisplayAsHiragana</source>
        <translation>ひらがなに表示切替</translation>
    </message>
    <message>
        <source>IMEOff</source>
        <translation>IME を無効化</translation>
    </message>
    <message>
        <source>IMEOn</source>
        <translation>IME を有効化</translation>
    </message>
    <message>
        <source>InputModeFullAlphanumeric</source>
        <translation>全角英数に入力切替</translation>
    </message>
    <message>
        <source>InputModeFullKatakana</source>
        <translation>全角カタカナに入力切替</translation>
    </message>
    <message>
        <source>InputModeHalfAlphanumeric</source>
        <translation>半角英数に入力切替</translation>
    </message>
    <message>
        <source>InputModeHalfKatakana</source>
        <translation>半角カタカナに入力切替</translation>
    </message>
    <message>
        <source>InputModeHiragana</source>
        <translation>ひらがなに入力切替</translation>
    </message>
    <message>
        <source>InsertAlternateSpace</source>
        <translation>代替空白文字を入力</translation>
    </message>
    <message>
        <source>InsertFullSpace</source>
        <translation>全角空白を入力</translation>
    </message>
    <message>
        <source>InsertHalfSpace</source>
        <translation>半角空白を入力</translation>
    </message>
    <message>
        <source>InsertSpace</source>
        <translation>空白を入力</translation>
    </message>
    <message>
        <source>MoveCursorLeft</source>
        <translation>カーソルを左に移動</translation>
    </message>
    <message>
        <source>MoveCursorRight</source>
        <translation>カーソルを右に移動</translation>
    </message>
    <message>
        <source>MoveCursorToBeginning</source>
        <translation>カーソルを左端に移動</translation>
    </message>
    <message>
        <source>MoveCursorToEnd</source>
        <translation>カーソルを右端に移動</translation>
    </message>
    <message>
        <source>PredictAndConvert</source>
        <translation>予測変換</translation>
    </message>
    <message>
        <source>SegmentFocusFirst</source>
        <translation>文節を左端に移動</translation>
    </message>
    <message>
        <source>SegmentFocusLast</source>
        <translation>文節を右端に移動</translation>
    </message>
    <message>
        <source>SegmentFocusLeft</source>
        <translation>文節を左に移動</translation>
    </message>
    <message>
        <source>SegmentFocusRight</source>
        <translation>文節を右に移動</translation>
    </message>
    <message>
        <source>SegmentWidthExpand</source>
        <translation>文節を伸ばす</translation>
    </message>
    <message>
        <source>SegmentWidthShrink</source>
        <translation>文節を縮める</translation>
    </message>
    <message>
        <source>SwitchKanaType</source>
        <translation>ひらがな・カタカナを切替</translation>
    </message>
    <message>
        <source>ToggleAlphanumericMode</source>
        <translation>英数入力切り替え</translation>
    </message>
    <message>
        <source>LaunchConfigDialog</source>
        <translation>プロパティを起動</translation>
    </message>
    <message>
        <source>LaunchDictionaryTool</source>
        <translation>辞書ツールを起動</translation>
    </message>
    <message>
        <source>LaunchWordRegisterDialog</source>
        <translation>単語登録を起動</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>確定取り消し</translation>
    </message>
    <message>
        <source>SegmentFocusRightOrCommit</source>
        <translation>文節を右に移動または確定</translation>
    </message>
    <message>
        <source>Reconvert</source>
        <translation>再変換</translation>
    </message>
</context>
</TS>
